@@ -8,6 +8,7 @@ from urllib.error import HTTPError
 import pandas as pd
 from minio import Minio
 from minio.commonconfig import Tags
+import requests
 
 from miniops.utils import log_memory_usage
 
@@ -44,13 +45,16 @@ class MinioAgent(ABC):
     def process_generator(self, dataframe_generator, object_names: List[str]) -> List[str]:
         skipped = []
         for counter, dataframe in enumerate(dataframe_generator):
-            logging.info(
-                f"processing dataframe #{counter+1}, with {len(dataframe)} items"
-            )
             if dataframe is not None:
+                logging.info(
+                    f"processing dataframe #{counter+1}, with {len(dataframe)} items"
+                )
                 log_memory_usage()
                 self.process(dataframe)
             else:
+                logging.info(
+                    f"skipping dataframe #{counter+1} {object_names[counter]}"
+                )
                 skipped.append(object_names[counter])
         return skipped
 
@@ -70,9 +74,8 @@ class MinioAgent(ABC):
     ) -> Optional[pd.DataFrame]:
         for counter in range(max_retries):
             try:
-                dataframe = pd.read_json(
-                    f"{self.hostname}/{bucket_name}/{object_name}", lines=True
-                )
+                object_text = requests.get(f"{self.hostname}/{bucket_name}/{object_name}", proxies={}).text
+                dataframe = pd.read_json(object_text, lines=True)
                 return dataframe
             except HTTPError:
                 first_sentence = f"Could not read {object_name} from {bucket_name}, attempt: {counter+1}."
@@ -100,12 +103,16 @@ class MinioAgent(ABC):
                 yield None
 
     def is_already_processed(self, object_name: str, bucket_name: str) -> bool:
-        tags = {}
-        tags = self.client.get_object_tags(bucket_name, object_name)
-        if f"{self.name}-processed" in tags:
-            already_processed = tags[f"{self.name}-processed"]
-        else:
+        already_processed = False
+        try:
+            tags = self.client.get_object_tags(bucket_name, object_name)
+            if f"{self.name}-processed" in tags:
+                already_processed = tags[f"{self.name}-processed"]
+            else:
+                already_processed = False
+        except TypeError:
             already_processed = False
+        return already_processed
 
     def filter_objects_todo(
         self, object_names: List[str], bucket_name: str
